//////////////////////////////////////////////////////////////////////////
//
//  ct_windows.h    window pairs, globals (window handles etc.) 
//
//////////////////////////////////////////////////////////////////////////

#ifndef CT_WINDOWS_H
#define CT_WINDOWS_H

#include <iostream>

//Disable min, max macros -- this is required for MathUtil.h to compile.
//Otherwise min, max are brought in by  windows.h 
#define NOMINMAX     

#include <windows.h>   // Win32 APIs
#include <wincon.h>    // Windows console

// GLOBALS: window handles. Used by graphics and mouse functions. Hide them later.

extern HWND hConsoleWindowHandle;
extern HWND hGraphicWindowHandle;

// GLOBALS: mouse state. Retrieved by routines from ct_mouse

enum BUTTON_STATE { BUTTON_UP, BUTTON_DOWN } ;
extern BUTTON_STATE buttonState; 

extern int   xMousePos;     // mouse position
extern int   yMousePos;  

// GLOBALS: for graphics

extern HPEN      hCurrentPen;
extern HBRUSH    hCurrentBrush;
extern int       currentPenPointX; 
extern int       currentPenPointY; 

// Windows constants
// Knowledge of window parameters is required for 
//   getting the size of the client area right

const int GRAPHICS_WINDOW_WIDTH = 400;
const int GRAPHICS_WINDOW_HEIGHT = 400;
const int TITLE_BAR_HEIGHT = 25;
const int WINDOW_BORDER_WIDTH = 6;
const int GRAPHICS_WINDOW_OFFSET_X = 100;
const int GRAPHICS_WINDOW_OFFSET_Y = 100;
const int CONSOLE_WINDOW_WIDTH = 600;
const int CONSOLE_WINDOW_HEIGHT = 300; 

// Window Handler functions

long WINAPI WindowProc(HWND hWnd,                // graphics window event handler 
                       UINT message, 
                       WPARAM wParam, 
                       LPARAM lParam); 

HWND GetConsoleHwnd(void);                       //get console window handle

DWORD WINAPI GraphicWindowThreadFunc( LPVOID );  // graphics window thread

// WindowPair : Create a graphics windows and its thread with message loop.
//              Will be used for all window pairs; will take arguments then.

void WindowPair();

inline void BigSquarePair(){
    WindowPair();
}

#endif // CT_WINDOWS_H 



